:py:mod:`key_press_com`
=======================

.. py:module:: key_press_com


Module Contents
---------------

.. py:data:: current_dir
   

   

.. py:data:: current_dir
   

   

.. py:data:: Exec
   

   Properties of the generated Node


.. py:data:: BaseName
   :annotation: = Key Press

   

.. py:data:: NodeAttributeNames
   :annotation: = ['Parameters', 'Key Out']

   

.. py:data:: NodeAttributeType
   :annotation: = ['Static', 'Output']

   

.. py:data:: ParameterNames
   :annotation: = ['Visualisation', 'Key']

   

.. py:data:: ParameterTypes
   :annotation: = ['bool', 'str']

   

.. py:data:: ParametersDefaultValues
   :annotation: = [False, 'a']

   

.. py:data:: WorkerDefaultExecutable
   

   

.. py:data:: key_com
   

   

